@@ -28,6 +28,7 @@ from pptx.dml.color import RGBColor
 
 from docx import Document
 from docx.shared import Inches, Pt as DocxPt
+from docx.image.exceptions import UnrecognizedImageError
 from PIL import Image
 
 from pptx import Presentation
@@ -138,7 +139,7 @@ def search_for_imgfile(imgfile, tmp_dir, targetdir):
         imgfile2 = os.path.join(dirname, os.path.basename(imgfile))
         if os.path.isfile(imgfile2):
             return imgfile2
-    raise Exception("Image file {} not found".format(imgfile))
+    raise Exception("Image file {} not found\n".format(imgfile))
 
 
 def parse_single_size(ssize, dpi=120, emsize=25):
@@ -1270,6 +1271,9 @@ class DocxExporter(BaseExporter):
 
             for run in parse_4s_elem(el):
                 if run[0] == "img":
+                    if run[1].endswith(".shtml"):
+                        r = para.add_run("(ТУТ БЫЛА ССЫЛКА НА ПРОТУХШУЮ КАРТИНКУ)\n")  # TODO: добавить возможность пропускать кривые картинки опцией
+                        continue
                     parsed_image = parseimg(
                         run[1],
                         dimensions="inches",
@@ -1280,7 +1284,10 @@ class DocxExporter(BaseExporter):
                     width = parsed_image["width"]
                     height = parsed_image["height"]
                     r = para.add_run("\n")
-                    r.add_picture(imgfile, width=Inches(width), height=Inches(height))
+                    try:
+                        r.add_picture(imgfile, width=Inches(width), height=Inches(height))
+                    except UnrecognizedImageError:
+                        sys.stderr.write(f"python-docx can't recognize header for {imgfile}.\n")
                     r.add_text("\n")
                     continue
 
@@ -1289,7 +1296,7 @@ class DocxExporter(BaseExporter):
                     r.italic = True
                 elif run[0] == "sc":
                     r.small_caps = True
-                if whiten and not args.nospoilers:
+                if whiten and not args.nospoilers and not args.pagebreakspoilers:
                     r.style = "Whitened"
 
     def add_question(self, element):
@@ -1318,7 +1325,10 @@ class DocxExporter(BaseExporter):
         self._docx_format(q["question"], p, False)
 
         if not args.noanswers:
-            p = self.doc.add_paragraph()
+            if args.pagebreakspoilers:
+                p = self.doc.add_page_break()
+            else:
+                p = self.doc.add_paragraph()
             p.paragraph_format.keep_together = True
             p.paragraph_format.space_before = DocxPt(6)
             p.add_run(f"{self.get_label(q, 'answer')}: ").bold = True
@@ -1450,14 +1460,15 @@ class PptxExporter(BaseExporter):
         s = s.replace("]\n", "]\n\n")
         return s
 
-    def pptx_process_text(self, s, image=None):
+    def pptx_process_text(self, s, image=None, strip_brackets=True):
         hs = self.labels["question_labels"]["handout_short"]
         if isinstance(s, list):
             for i in range(len(s)):
                 s[i] = self.pptx_process_text(s[i], image=image)
             return s
         s = s.replace("\u0301", "")
-        s = self.remove_square_brackets(s)
+        if strip_brackets:
+            s = self.remove_square_brackets(s)
         if image:
             s = re.sub("\\[" + hs + "(.+?)\\]", "", s, flags=re.DOTALL)
             s = s.strip()
@@ -1720,10 +1731,12 @@ class PptxExporter(BaseExporter):
         tf = textbox.text_frame
         tf.word_wrap = True
 
-        text_for_size = self.recursive_join(self.pptx_process_text(q["answer"]))
+        text_for_size = self.recursive_join(
+            self.pptx_process_text(q["answer"], strip_brackets=False)
+        )
         if q.get("zachet") and self.c.get("add_zachet"):
             text_for_size += "\n" + self.recursive_join(
-                self.pptx_process_text(q["zachet"])
+                self.pptx_process_text(q["zachet"], strip_brackets=False)
             )
         if q.get("comment") and self.c.get("add_comment"):
             text_for_size += "\n" + self.recursive_join(
@@ -1733,9 +1746,11 @@ class PptxExporter(BaseExporter):
         r = p.add_run()
         r.text = f"{self.get_label(q, 'answer')}: "
         r.font.bold = True
-        self.pptx_format(self.pptx_process_text(q["answer"]), p, tf, slide)
+        self.pptx_format(
+            self.pptx_process_text(q["answer"], strip_brackets=False), p, tf, slide
+        )
         if q.get("zachet") and self.c.get("add_zachet"):
-            zachet_text = self.pptx_process_text(q["zachet"])
+            zachet_text = self.pptx_process_text(q["zachet"], strip_brackets=False)
             r = p.add_run()
             r.text = f"\n{self.get_label(q, 'zachet')}: "
             r.font.bold = True
